powered by
is without argument and returns the current price of financial instruments as well as their variations, their opening prices, their max etc.
today.market()
data.frame
if (FALSE) today.market()
Run the code above in your browser using DataLab